@@ -80,8 +80,9 @@ func exampleInfo() *nfpm.Info {
 				PostRemove:  "../testdata/scripts/postremove.sh",
 			},
 			RPM: nfpm.RPM{
-				Group:    "foo",
-				Prefixes: []string{"/opt"},
+				Group:     "foo",
+				BuildHost: "barhost",
+				Prefixes:  []string{"/opt"},
 				Scripts: nfpm.RPMScripts{
 					PreTrans:  "../testdata/scripts/pretrans.sh",
 					PostTrans: "../testdata/scripts/posttrans.sh",
@@ -139,6 +140,10 @@ func TestRPM(t *testing.T) {
 	require.NoError(t, err)
 	require.Equal(t, "foo", group)
 
+	buildhost, err := rpm.Header.GetString(rpmutils.BUILDHOST)
+	require.NoError(t, err)
+	require.Equal(t, "barhost", buildhost)
+
 	summary, err := rpm.Header.GetString(rpmutils.SUMMARY)
 	require.NoError(t, err)
 	require.Equal(t, "Foo does things", summary)
@@ -751,12 +756,12 @@ func TestRPMChangelog(t *testing.T) {
 		notes := strings.Split(allNotes[i], "\n")
 
 		require.Equal(t, entry.Date, timestamp)
-		require.True(t, strings.Contains(title, entry.Packager))
-		require.True(t, strings.Contains(title, entry.Semver))
+		require.Contains(t, title, entry.Packager)
+		require.Contains(t, title, entry.Semver)
 		require.Equal(t, len(entry.Changes), len(notes))
 
 		for j, change := range entry.Changes {
-			require.True(t, strings.Contains(notes[j], change.Note))
+			require.Contains(t, notes[j], change.Note)
 		}
 	}
 }
